package com.alterdekim.game.controller;

import com.alterdekim.game.component.GameServer;
import com.alterdekim.game.component.StartUpListener;
import com.alterdekim.game.service.UserService;
import com.alterdekim.game.utils.DateUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.env.Environment;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.text.SimpleDateFormat;
import java.time.Duration;
import java.time.temporal.ChronoUnit;
import java.util.Date;

@Slf4j
@RestController
@RequestMapping("/api")
public class ApiController {
    @Autowired
    private Environment env;

    @Autowired
    private StartUpListener startUpListener;

    @Autowired
    private GameServer gameServer;

    @Autowired
    private UserService userService;

    @GetMapping("/get_dashboard_logs")
    public ResponseEntity<byte[]> getLogs() {
        try {
            Path logFile = Paths.get(env.getProperty("logging.file.name"));
            RandomAccessFile file = new RandomAccessFile(logFile.toFile(), "r");
            int n = 2048;
            file.seek(logFile.toFile().length() - n);
            byte[] b = new byte[n];
            file.read(b, 0, n);
            return ResponseEntity.ok(b);
        } catch (IOException e) {
            log.error("getLogs error: {}", e.getMessage());
            return ResponseEntity.badRequest().build();
        }
    }

    @GetMapping("/get_uptime")
    public ResponseEntity<String> getUpTime() {
        return ResponseEntity.ok(
                DateUtils.prettyPrint(Duration.of(System.currentTimeMillis() - startUpListener.getStartTime(), ChronoUnit.MILLIS))
        );
    }

    @GetMapping("/get_players_online")
    public ResponseEntity<Integer> getPlayersOnline() {
        return ResponseEntity.ok(gameServer.getPlayersCount());
    }

    @GetMapping("/get_users_count")
    public ResponseEntity<Long> getUsersCount() {
        return ResponseEntity.ok(userService.getUsersCount());
    }
}
